@@ -35,7 +35,7 @@
 
 #define SRCDIR TEST_SRCDIR"/conf"
 
-#ifdef NM_VPN_OLD
+#if ((NETWORKMANAGER_COMPILATION) & NM_NETWORKMANAGER_COMPILATION_WITH_LIBNM_UTIL)
 #define TMPDIR TEST_BUILDDIR"/conf-tmp-old"
 #else
 #define TMPDIR TEST_BUILDDIR"/conf-tmp-new"
@@ -237,8 +237,7 @@ remove_secrets (NMConnection *connection)
 	for (iter = keys; iter; iter = g_slist_next (iter))
 		nm_setting_vpn_remove_secret (s_vpn, (const char *) iter->data);
 
-	g_slist_foreach (keys, (GFunc) g_free, NULL);
-	g_slist_free (keys);
+	g_slist_free_full (keys, g_free);
 }
 
 static void
@@ -1049,7 +1048,7 @@ test_route_import (void)
 	/* IP4 setting */
 	s_ip4 = nm_connection_get_setting_ip4_config (connection);
 	g_assert (s_ip4);
-#ifdef NM_VPN_OLD
+#if ((NETWORKMANAGER_COMPILATION) & NM_NETWORKMANAGER_COMPILATION_WITH_LIBNM_UTIL)
 	{
 		NMIP4Route *route;
 		const char *expected_nh2   = "0.0.0.0";
